/// Contains a base class for all mde exceptions.
module mde.exception;

/** Base class for all mde Exceptions.
 *
 * All packages should have their own base exception type extending this one, and for each package
 * level a CTOR taking a message should pass the message to the super prepended with "package: ".
 * The performance of this is unimportant since exceptions are only intended for recovering from
 * unexpected errors anyway. A CTOR not taking a message and calling the super without a parameter
 * should also be provided.
 */
class mdeException : Exception {
    const symbol = "mde";	/// Override in derived classes.
    this (char[] msg) {
        super(symbol ~ ": " ~ msg);
    }
    this () {
        super("");	// Exception doesn't have a this() CTOR
    }
}

class initException : mdeException {
    const override symbol = super.symbol ~ ".init";
    this (char[] msg) {
        super(msg);
    }
}

class DynamicLibraryLoadException : initException {
    this (char[] msg) {
        super("when loading dynamic library: " ~ msg);
    }
}
